# from jetline.data.data import Data
# from jetline.data.helper import choose_file
#
#
# class YourDataClass(Data):
#     def __init__(self):
#         super().__init__(
#             name="Name",
#             data=choose_file(),
#
#         )
#
#     class Meta:
#         description = "This is the description for viz"
#         y = 0
#         x = 0



# from jetline.pipeline.pipeline import Pipeline
# from jetline.pipeline.node import Node
# from __PIPE__ import nodes as func
#
#
# def register(data_manager) -> Pipeline:
#     return Pipeline(
#         nodes=[
#             Node(
#                 function=func.node_function_1,
#                 inputs=["Name"],
#                 outputs=["Name"],
#                 viz={"y": 150, "x": 0, "sources": ['Name']}
#             ),
#         ],
#         data_manager=data_manager)
